@@ -1,7 +1,7 @@
 <?php
 /*
  UWiKiCMS is a lightweight web content management system.
- Copyright (C) 2005, 2006, 2007, 2009, 2013 Christian Mauduit <ufoot@ufoot.org>
+ Copyright (C) 2005, 2006, 2007, 2009, 2013, 2015 Christian Mauduit <ufoot@ufoot.org>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
@@ -166,7 +166,7 @@ class UWC_Content {
 	array_push($this->rss, 
 		   array("path"=>$row["content_path"],
 			 "title"=>$row["content_title"],
-			 "text"=>$row["content_text"],
+			 "text"=>uwc_format_no_markup($row["content_text"]),
 			 "date_update"=>$row["content_date_update"]));
       }
       $this->data->query_select_free();
