@@ -1,7 +1,7 @@
 <?php
 /*
  UWiKiCMS is a lightweight web content management system.
- Copyright (C) 2005, 2006, 2007, 2009, 2013 Christian Mauduit <ufoot@ufoot.org>
+ Copyright (C) 2005, 2006, 2007, 2009, 2013, 2015 Christian Mauduit <ufoot@ufoot.org>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
@@ -20,6 +20,7 @@
 */
 
 define("UWC_FORMAT_LONGDESC_CUT", 80);
+define("UWC_FORMAT_TWITTER_CUT", 100);
 
 function uwc_format_escape_sql($str) {
   $str=uwc_format_unescape_gpc($str);
@@ -61,14 +62,22 @@ function uwc_format_text_to_html($str) {
   return uwc_format_htmlfriendly(htmlentities($str,ENT_COMPAT|ENT_XHTML,"ISO-8859-15"));
 }
 
+function uwc_format_html_to_text($str) {
+  return html_entity_decode($str,ENT_COMPAT|ENT_XHTML,"ISO-8859-15");
+}
+
 function uwc_format_html_to_xul($str) {
-  return htmlspecialchars(html_entity_decode($str),ENT_COMPAT|ENT_XHTML,"ISO-8859-15");
+  return htmlspecialchars(uwc_format_html_to_text($str,ENT_COMPAT|ENT_XHTML,"ISO-8859-15"));
 }
 
 function uwc_format_text_to_xul($str) {
   return uwc_format_html_to_xul(uwc_format_text_to_html($str));
 }
 
+function uwc_format_html_to_twitter($str) {
+  return iconv("ISO-8859-15","UTF-8",uwc_format_cut_text(uwc_format_html_to_text($str),UWC_FORMAT_TWITTER_CUT));
+}
+
 function uwc_format_text_to_html_attribute($str) {
   /*
    * Usefull to format stuff for html attributes like
@@ -213,7 +222,22 @@ function uwc_format_escape_rss($var) {
 		     ">" => "&gt;",
 		     "<" => "&lt;",
 		     '"' => "&quot;",
-		     "'" => "&apos;"));
+		     "'" => "&apos;",
+		     "\r" => " ",
+		     "\n" => " ",
+		     "\t" => " "));
+
+  return $var;
+}
+
+function uwc_format_no_markup($var) {
+  $var = preg_replace("/\[([^\|\]]+)\|([^\|\]]+)\]/","\$1",$var);
+  $var = preg_replace("/\[([^\|\]]+)\]/","",$var);
+  $var = preg_replace("/^[\#\*\!]+/","",$var);
+  $var = preg_replace("/[\r\n][\#\*\!]+/","",$var);
+  $var = preg_replace("/[[:cntrl:][:space:]]+/"," ",$var);
+  $var = preg_replace("/^ +/","",$var);
+  $var = preg_replace("/ +\$/","",$var);
 
   return $var;
 }
@@ -225,4 +249,4 @@ function uwc_format_html_to_rss($var) {
   return $var;
 }
 
-?>
\ No newline at end of file
+?>
