@@ -1,7 +1,7 @@
 <?php
 /*
  UWiKiCMS is a lightweight web content management system.
- Copyright (C) 2005, 2006, 2007, 2009, 2013 Christian Mauduit <ufoot@ufoot.org>
+ Copyright (C) 2005, 2006, 2007, 2009, 2013, 2015 Christian Mauduit <ufoot@ufoot.org>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
@@ -174,6 +174,10 @@ class UWC_Image {
     return null;
   }
 
+  function get_images_list() {
+    return Array();
+  }
+
   function get_rss() {
     return null;
   }
