@@ -1,7 +1,7 @@
 <?php
 /*
  UWiKiCMS is a lightweight web content management system.
- Copyright (C) 2005, 2006, 2007, 2009, 2013 Christian Mauduit <ufoot@ufoot.org>
+ Copyright (C) 2005, 2006, 2007, 2009, 2013, 2015 Christian Mauduit <ufoot@ufoot.org>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
@@ -131,7 +131,12 @@ $this->messages=array
    "gallery_next"=>"Next image",
    "gallery_empty"=>"No images in this gallery",
    "google_search"=>"Google search",
+   "rss"=>"%s RSS feed",
    "rss_about"=>"RSS feed for %s",
+   "facebook"=>"Share %s on facebook",
+   "facebook_about"=>"Share %s on facebook",
+   "twitter"=>"Tweet %s",
+   "twitter_about"=>"Share %s on Twitter",
    "do_date_update"=>"Update last modification date",
 
    "" => ""
