@@ -1,7 +1,7 @@
 <?php
 /*
  UWiKiCMS is a lightweight web content management system.
- Copyright (C) 2005, 2006, 2007, 2009, 2013 Christian Mauduit <ufoot@ufoot.org>
+ Copyright (C) 2005, 2006, 2007, 2009, 2013, 2015 Christian Mauduit <ufoot@ufoot.org>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
@@ -42,7 +42,7 @@ require("horde.php");
 require("gallery.php");
 require("rss.php");
 
-define("UWC_PAGE_DESCRIPTION_SIZE",80);
+define("UWC_PAGE_DESCRIPTION_SIZE",300);
 
 class UWC_Page {
   var $context=false;
@@ -280,6 +280,22 @@ class UWC_Page {
     return $this->conf->rss_height;
   }
 
+  function get_facebook_width() {
+    return $this->conf->facebook_width;
+  }
+
+  function get_facebook_height() {
+    return $this->conf->facebook_height;
+  }
+
+  function get_twitter_width() {
+    return $this->conf->twitter_width;
+  }
+
+  function get_twitter_height() {
+    return $this->conf->twitter_height;
+  }
+
   function get_news_max_nb() {
     return $this->conf->news_max_nb;
   }
@@ -524,6 +540,29 @@ class UWC_Page {
     return $domain_name;
   }
 
+  function has_images() {
+    $list=$this->content->get_images_list();
+    return $list && count($list)>0;
+  }
+
+  function get_first_image_url_clean() {
+    $id=null;
+    $list=$this->content->get_images_list();
+    if ($list && count($list)>0) {
+      $keys=array_keys($list);
+      $id=$keys[0];
+    }
+    if ($id) {
+      return $this->make_url(uwc_image_make_full_url(uwc_content_get_parent_path($this->get_path()),$id),array("login"=>"","password"=>"","session"=>"","css"=>"","action"=>""));
+    } else {
+      return "";
+    }
+  }
+
+  function get_first_image_absolute_url_clean() {
+    return $this->make_absolute_url_clean($this->get_first_image_url_clean());
+  }
+
   function get_absolute_url() {
     return $this->conf->siteurl.$this->make_url($this->get_path(),array("login"=>"","password"=>""));
   }
@@ -556,6 +595,14 @@ class UWC_Page {
     return $this->make_url($this->get_path(),array("login"=>"","password"=>"","session"=>"","css"=>"","action"=>"rss"));
   }
 
+  function get_facebook_url() {
+    return sprintf("https://www.facebook.com/sharer.php?u=%s",urlencode($this->get_absolute_url_clean()));
+  }
+
+  function get_twitter_url() {
+      return sprintf("https://twitter.com/intent/tweet?text=%s&url=%s",urlencode(uwc_format_html_to_twitter($this->get_title()." ".$this->get_meta_description())),urlencode($this->get_absolute_url_clean()));
+  }
+
   function get_css_yes_url() {
     return $this->make_url($this->get_path(),array("css"=>"yes"));
   }
@@ -860,7 +907,7 @@ class UWC_Page {
   }
 
   function get_meta_description() {
-    return $this->get_home_title();
+    return uwc_format_text_to_html(uwc_format_cut_text(uwc_format_no_markup($this->content->get_text()),UWC_PAGE_DESCRIPTION_SIZE));
   }
 
   function get_meta_keywords() {
@@ -1033,7 +1080,7 @@ class UWC_Page {
   }
 
   function need_nav() {
-    return $this->need_home() || $this->need_up() || $this->need_next() || $this->need_prev() || $this->need_rss();
+    return $this->need_home() || $this->need_up() || $this->need_next() || $this->need_prev() || $this->need_rss() || $this->need_share();
   }
 
   function need_home() {
@@ -1056,6 +1103,10 @@ class UWC_Page {
     return $this->content->get_status()==0;
   }
 
+  function need_share() {
+    return $this->content->get_status()==0;
+  }
+
   function include_external() {
     uwc_external_include($this);
   }
