@@ -1,7 +1,7 @@
 <?php
 /*
  UWiKiCMS is a lightweight web content management system.
- Copyright (C) 2005, 2006, 2007, 2009, 2013 Christian Mauduit <ufoot@ufoot.org>
+ Copyright (C) 2005, 2006, 2007, 2009, 2013, 2015 Christian Mauduit <ufoot@ufoot.org>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
@@ -35,6 +35,19 @@
     <link rel="stylesheet" type="text/css" media="screen" href="<?php echo $this->get_css_dir(); ?>/layout.css" />
     <link rel="stylesheet" type="text/css" media="print" href="<?php echo $this->get_css_dir(); ?>/print.css" />
     <link rel="shortcut icon" href="/favicon.ico" type="image/x-icon" />
+<?php } ?>
+    <meta property="og:title" content="<?php echo $this->get_title(); ?>"/>
+    <meta property="og:description" content="<?php echo $this->get_meta_description(); ?>"/>
+    <meta property="og:type" content="article"/>
+    <meta property="og:url" content="<?php echo $this->get_absolute_url(); ?>"/>
+    <meta name="twitter:card" content="summary"/>
+    <meta name="twitter:site" content="<?php echo $this->get_meta_author(); ?>"/>
+    <meta name="twitter:title" content="<?php echo $this->get_title(); ?>"/>
+    <meta name="twitter:description" content="<?php echo $this->get_meta_description(); ?>"/>
+    <meta name="twitter:url" content="<?php echo $this->get_absolute_url(); ?>"/>
+<?php if ($this->has_images()) { ?>
+    <meta property="og:image" content="<?php echo $this->get_first_image_absolute_url_clean(); ?>"/>
+    <meta name="twitter:image" content="<?php echo $this->get_first_image_absolute_url_clean(); ?>"/>
 <?php } ?>
   </head>
   <body>
@@ -76,7 +89,13 @@
     <?php } ?>
 
     <?php if ($this->need_rss()) { ?>
-    <?php if ($this->need_home() || $this->need_prev() || $this->need_up() || $this->need_next()) { ?><span class="textmode"> | </span><?php } ?><a href="<?php echo $this->get_rss_url(); ?>"><img src="<?php echo $this->get_images_dir(); ?>/rss.png" width="<?php echo $this->get_rss_width(); ?>" height="<?php echo $this->get_rss_height(); ?>" alt="<?php echo sprintf($this->translate("rss"),$this->get_title()); ?>" title="<?php echo sprintf($this->translate("rss_about"),$this->get_title()); ?>" class="msiehackbox" /></a>
+    <?php if ($this->need_home() || $this->need_prev() || $this->need_up() || $this->need_next()) { ?><span class="textmode"> | </span><?php } ?>
+    <a href="<?php echo $this->get_rss_url(); ?>"><img src="<?php echo $this->get_images_dir(); ?>/rss.png" width="<?php echo $this->get_rss_width(); ?>" height="<?php echo $this->get_rss_height(); ?>" alt="<?php echo sprintf($this->translate("rss"),$this->get_title()); ?>" title="<?php echo sprintf($this->translate("rss_about"),$this->get_title()); ?>" class="msiehackbox" /></a>
+    <?php } ?>
+    <?php if ($this->need_share()) { ?>
+    <?php if ($this->need_home() || $this->need_prev() || $this->need_up() || $this->need_next() || $this->need_rss()) { ?><span class="textmode"> | </span><?php } ?>
+    </span><a href="<?php echo $this->get_facebook_url(); ?>"><img src="<?php echo $this->get_images_dir(); ?>/facebook.png" width="<?php echo $this->get_facebook_width(); ?>" height="<?php echo $this->get_facebook_height(); ?>" alt="<?php echo sprintf($this->translate("facebook"),$this->get_title()); ?>" title="<?php echo sprintf($this->translate("facebook_about"),$this->get_title()); ?>" class="msiehackbox" /></a>
+    <span class="textmode"> | </span><a href="<?php echo $this->get_twitter_url(); ?>"><img src="<?php echo $this->get_images_dir(); ?>/twitter.png" width="<?php echo $this->get_twitter_width(); ?>" height="<?php echo $this->get_twitter_height(); ?>" alt="<?php echo sprintf($this->translate("twitter"),$this->get_title()); ?>" title="<?php echo sprintf($this->translate("twitter_about"),$this->get_title()); ?>" class="msiehackbox" /></a>
     <?php } ?>
 
     <span class="textmode"> ] </span>
@@ -93,7 +112,7 @@ if (count($langs)>0) {
       <span class="textmode"> | </span>
     <?php }
       $first=false; ?>
-      <a href="<?php echo $this->get_translate_url($lang); ?>"><img src="<?php echo $this->get_images_dir()."/flag_".$lang.".png"; ?>" width="<?php echo $this->get_lang_width(); ?>" height="<?php echo $this->get_lang_height(); ?>" alt="<?php echo $this->translate("view_lang_".$lang); ?>" title="<?php echo $this->translate("view_lang_".$lang); ?>" class="msiehackbox" /></a>
+      <a href="<?php echo $this->get_translate_url($lang); ?>" hreflang="<?php echo $lang; ?>"><img src="<?php echo $this->get_images_dir()."/flag_".$lang.".png"; ?>" width="<?php echo $this->get_lang_width(); ?>" height="<?php echo $this->get_lang_height(); ?>" alt="<?php echo $this->translate("view_lang_".$lang); ?>" title="<?php echo $this->translate("view_lang_".$lang); ?>" class="msiehackbox" /></a>
     <?php } ?>
     <span class="textmode"> ] </span>
     </div>
