@@ -1,7 +1,7 @@
 <?php
 /*
  UWiKiCMS is a lightweight web content management system.
- Copyright (C) 2005, 2006, 2007, 2009, 2013 Christian Mauduit <ufoot@ufoot.org>
+ Copyright (C) 2005, 2006, 2007, 2009, 2013, 2015 Christian Mauduit <ufoot@ufoot.org>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
@@ -83,7 +83,7 @@
        <?php $first=true; ?>
      <?php foreach ($this->get_untranslated() as $lang) { ?>
        <?php if (!$first) { echo " | "; } $first=false; ?>
-<a href="<?php echo $this->get_translate_url($lang); ?>"><?php echo $lang; ?></a>
+<a href="<?php echo $this->get_translate_url($lang); ?>" hreflang="<?php echo $lang; ?>"><?php echo $lang; ?></a>
 <?php } ?>
        </li>
 <?php } ?>
